# to appease R CMD check
# most of these are in R/app.R
utils::globalVariables(
  c("L1",
    "L2",
    "n",
    ":=",
    "nobs",
    "count",
    "V1",
    "y",
    "output",
    "x",
    "check_harmony",
    "Cat1",
    "V2",
    "..LV..",
    "data_mutate[[gran1]]",
    "data_mutate[[gran2]]",
    "value",
    "granularity2",
    "ymin",
    "ymax",
    "data_mutate_obj",
    "gini_meas",
    "total_gini_meas",
    "quantiles",
    "mean_max_variation",
    "newds",
    "freqx",
    "..density..")
)
